summaryrefslogtreecommitdiffstats
path: root/src/modules/dcc/descriptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/dcc/descriptor.h')
-rw-r--r--src/modules/dcc/descriptor.h72
1 files changed, 36 insertions, 36 deletions
diff --git a/src/modules/dcc/descriptor.h b/src/modules/dcc/descriptor.h
index f3f6c3f3..49a705ce 100644
--- a/src/modules/dcc/descriptor.h
+++ b/src/modules/dcc/descriptor.h
@@ -46,7 +46,7 @@ protected:
KviStr m_szZeroPortRequestTag;
unsigned int m_uId; // this dcc session ID
- QString m_szId;
+ TQString m_szId;
KviDccWindow * m_pDccWindow; // 0 if it has no window
KviDccFileTransfer * m_pDccTransfer; // 0 if it is not a transfer
@@ -69,8 +69,8 @@ public:
void setZeroPortRequestTag(const KviStr &szTag){ m_szZeroPortRequestTag = szTag; };
unsigned int id() const { return m_uId; };
- const QString & idString() const { return m_szId; };
- static KviDccDescriptor * find(unsigned int uId);
+ const TQString & idString() const { return m_szId; };
+ static KviDccDescriptor * tqfind(unsigned int uId);
static KviPointerHashTable<int,KviDccDescriptor> * descriptorDict();
void triggerCreationEvent(); // this MUST be called by the creator of the descriptor!
@@ -78,28 +78,28 @@ public:
// void copyFrom(const KviDccDescriptor &src);
public:
// Generic parameters
- QString szType; // DCC protocol : CHAT , SCHAT , SEND , TSSEND....
+ TQString szType; // DCC protocol : CHAT , SCHAT , SEND , TSSEND....
bool bActive; // active or passive connection ?
- QString szNick; // remote user nickname
- QString szUser; // remote user name (unknown for passive dcc)
- QString szHost; // remote user host (unknown for passive dcc)
+ TQString szNick; // remote user nickname
+ TQString szUser; // remote user name (unknown for passive dcc)
+ TQString szHost; // remote user host (unknown for passive dcc)
- QString szLocalNick; // local user nickname (always from irc)
- QString szLocalUser; // local user username (always from irc)
- QString szLocalHost; // local user hostname (always from irc)
+ TQString szLocalNick; // local user nickname (always from irc)
+ TQString szLocalUser; // local user username (always from irc)
+ TQString szLocalHost; // local user hostname (always from irc)
- QString szIp; // remote user ip (active dcc only)
- QString szPort; // remote user port (active dcc only)
+ TQString szIp; // remote user ip (active dcc only)
+ TQString szPort; // remote user port (active dcc only)
- QString szListenIp; // passive only : ip to listen on
- QString szListenPort; // passive only : port to listen on
+ TQString szListenIp; // passive only : ip to listen on
+ TQString szListenPort; // passive only : port to listen on
bool bSendRequest; // passive only : true if we have to send the CTCP request
- QString szFakeIp; // passive only : fake ip to send in the CTCP
- QString szFakePort; // passive only : fake port to send in the CTCP
+ TQString szFakeIp; // passive only : fake ip to send in the CTCP
+ TQString szFakePort; // passive only : fake port to send in the CTCP
bool bDoTimeout; // the marshall has to setup a timeout ?
@@ -116,11 +116,11 @@ public:
// DCC SEND/RECV
- QString szFileName; // RECVFILE: incoming file name, SENDFILE: filename sent to the remote end
- QString szFileSize; // RECVFILE: incoming file size, SENDFILE: remote resume size
+ TQString szFileName; // RECVFILE: incoming file name, SENDFILE: filename sent to the remote end
+ TQString szFileSize; // RECVFILE: incoming file size, SENDFILE: remote resume size
- QString szLocalFileName; // RECVFILE: save file name selected, SENDFILE: file to send
- QString szLocalFileSize; // RECVFILE: local file size (to resume), SENDFILE: file to send size
+ TQString szLocalFileName; // RECVFILE: save file name selected, SENDFILE: file to send
+ TQString szLocalFileSize; // RECVFILE: local file size (to resume), SENDFILE: file to send size
bool bRecvFile; // do we have to RECEIVE the file or SEND it ?
@@ -134,23 +134,23 @@ public:
KviStr szCodec; // codec name
int iSampleRate; // Sample rate
public:
- // new interface... but should be converted to QString...
- QString protocol(){ return szType; };
+ // new interface... but should be converted to TQString...
+ TQString protocol(){ return szType; };
bool isActive(){ return bActive; };
- QString remoteNick(){ return szNick; };
- QString remoteUser(){ return szUser; };
- QString remoteHost(){ return szHost; };
- QString remoteIp(){ return szIp; };
- QString remotePort(){ return szPort; };
- QString remoteFileName(){ return szFileName; };
- QString remoteFileSize(){ return szFileSize; };
- QString localNick(){ return szLocalNick; };
- QString localUser(){ return szLocalUser; };
- QString localHost(){ return szLocalHost; };
- QString localIp(){ return szIp; };
- QString localPort(){ return szPort; };
- QString localFileName(){ return szLocalFileName; };
- QString localFileSize(){ return szLocalFileSize; };
+ TQString remoteNick(){ return szNick; };
+ TQString remoteUser(){ return szUser; };
+ TQString remoteHost(){ return szHost; };
+ TQString remoteIp(){ return szIp; };
+ TQString remotePort(){ return szPort; };
+ TQString remoteFileName(){ return szFileName; };
+ TQString remoteFileSize(){ return szFileSize; };
+ TQString localNick(){ return szLocalNick; };
+ TQString localUser(){ return szLocalUser; };
+ TQString localHost(){ return szLocalHost; };
+ TQString localIp(){ return szIp; };
+ TQString localPort(){ return szPort; };
+ TQString localFileName(){ return szLocalFileName; };
+ TQString localFileSize(){ return szLocalFileSize; };
bool isFileUpload();
bool isFileDownload();
bool isDccChat();